# pysid

This is a python System Identification package, based on numpy and scipy, that
provide some tools for parametric identification of causal linear time-invariant systems.

## Supported methods

Here are the list of the implemented methods
- Least Squares
- Instrumental Variables
- Prediction Error method

## Dependencies

Currently, this packages is based on numpy. For this reason, the basic package dependencies are:

- Numpy
- Scipy

## Installation

```pip install pysid```
